<?php
/*
Plugin Name: EDD RSS
Version: 1.0
Description: This plugin will be added edd products information into your feeds.
Plugin URI: http://ham3da.ir/
Author: Javad Ahshamian
Author URI: http://ham3da.ir/
Text Domain: edd-rss
License: Private
*/

add_action( 'pre_get_posts', 'add_my_post_types_to_query' );

function add_my_post_types_to_query( $query ) 
{
    global $edd_options;
    
    if(isset($edd_options['edd_rss_check']) && $edd_options['edd_rss_check'] != null)
    {
        $edd_rss_check = $edd_options['edd_rss_check'];
    }
    else
    {
        $edd_rss_check = '0';
    }
    
    
	if ( is_feed() && $query->is_feed() && $edd_rss_check == '1')
		$query->set( 'post_type', array('download', 'post' ) );
        $query->set('orderby', array('date' => 'DESC'));
	return $query;
}

if( !class_exists( 'EDD_RSS_Class' ) ) {
    /**
     * Main EDD_RSS_Class class
     *
     * @since       1.0.0
     */
    class EDD_RSS_Class 
    {
        /**
         * @var         EDD_RSS_Class $instance The one true EDD_RSS_Class
         * @since       1.0.0
         */
        private static $instance;
        /**
         * Get active instance
         *
         * @access      public
         * @since       1.0.0
         * @return      object self::$instance The one true EDD_RSS_Class
         */
        public static function instance() 
        {
            if( !self::$instance ) 
            {
                self::$instance = new EDD_RSS_Class();
                self::$instance->setup_constants();
                self::$instance->includes();
                self::$instance->load_textdomain();
                self::$instance->hooks();
            }
            return self::$instance;
        }
        /**
         * Setup plugin constants
         *
         * @access      private
         * @since       1.0.0
         * @return      void
         */
        private function setup_constants() 
        {
            // Plugin version
            define( 'EDD_RSS_VER', '1.0.0' );
            // Plugin path
            define( 'EDD_RSS_DIR', plugin_dir_path( __FILE__ ) );
            // Plugin URL
            define( 'EDD_RSS_URL', plugin_dir_url( __FILE__ ) );
        }
        /**
         * Include necessary files
         *
         * @access      private
         * @since       1.0.0
         * @return      void
         */
        private function includes() 
        {
            /**
             * @todo        The following files are not included in the boilerplate, but
             *              the referenced locations are listed for the purpose of ensuring
             *              path standardization in EDD extensions. Uncomment any that are
             *              relevant to your extension, and remove the rest.
             */
        }
        /**
         * Run action and filter hooks
         *
         * @access      private
         * @since       1.0.0
         * @return      void
         *
         * @todo        The hooks listed in this section are a guideline, and
         *              may or may not be relevant to your particular extension.
         *              Please remove any unnecessary lines, and refer to the
         *              WordPress codex and EDD documentation for additional
         *              information on the included hooks.
         *
         *              This method should be used to add any filters or actions
         *              that are necessary to the core of your extension only.
         *              Hooks that are relevant to meta boxes, widgets and
         *              the like can be placed in their respective files.
         *
         *              IMPORTANT! If you are releasing your extension as a
         *              commercial extension in the EDD store, DO NOT remove
         *              the license check!
         */
        private function hooks() 
        {
            // Register settings
            add_filter( 'edd_settings_sections_extensions', array( $this, 'settings_section' ) );
            add_filter( 'edd_settings_extensions', array( $this, 'settings' ), 1 );
            
        }
        
        /**
         * Internationalization
         *
         * @access      public
         * @since       1.0.0
         * @return      void
         */
        public function load_textdomain() 
        {
            $lang_dir = EDD_RSS_DIR . '/languages';
            load_plugin_textdomain('edd_rss', false, basename(dirname(__FILE__)).'/languages');
        }
        /**
         * Add settings
         *
         * @access      public
         * @since       1.0.0
         * @param       array $settings The existing EDD settings array
         * @return      array The modified EDD settings array
         */
        public function settings( $settings ) 
        {
            $settings['edd-rss'] = array(
                array(
                    'id'    => 'edd_rss_settings',
                    'name'  => '<strong>' . __( 'EDD Feeds Settings', 'edd_rss' ) . '</strong>',
                    'desc'  => __( 'Configure EDD Feeds Settings', 'edd_rss' ),
                    'type'  => 'header',
                    ),
            		array(
            			'id'    => 'edd_rss_check',
            			'name'  => __( 'Enable edd Feeds', 'edd_rss' ),
            			'desc'  => sprintf(__( 'Check this to added your edd products into your rss feeds. your site feeds Link: (%s)', 'edd_rss' ), '<span dir="ltr">'.get_feed_link().'</span>'),
            			'type'  => 'checkbox'
            		)
            );
            return $settings;

        }
        
        public function settings_section( $sections ) 
        {
            $sections['edd-rss'] = __( 'EDD RSS', 'edd_rss' );
            return $sections;
        }
        
    }
} // End if class_exists check
/**
 * The main function responsible for returning the one true EDD_RSS_Class
 * instance to functions everywhere
 *
 * @since       1.0.0
 * @return      \EDD_RSS_Class The one true EDD_RSS_Class
 *
 * @todo        Inclusion of the activation code below isn't mandatory, but
 *              can prevent any number of errors, including fatal errors, in
 *              situations where your extension is activated but EDD is not
 *              present.
 */
function EDD_RSS_load() 
{
    if( ! class_exists( 'Easy_Digital_Downloads' ) ) 
    {
        if( ! class_exists( 'EDD_Extension_Activation' ) ) 
        {
            load_plugin_textdomain('edd_rss', false, basename(dirname(__FILE__)).'/languages');
            require_once 'includes/class.extension-activation.php';
        }
        $activation = new EDD_Extension_Activation( plugin_dir_path( __FILE__ ), basename( __FILE__ ) );
        $activation = $activation->run();
    } 
    else 
    {
        return EDD_RSS_Class::instance();
    }
}
add_action( 'plugins_loaded', 'EDD_RSS_load' );
/**
 * The activation hook is called outside of the singleton because WordPress doesn't
 * register the call from within the class, since we are preferring the plugins_loaded
 * hook for compatibility, we also can't reference a function inside the plugin class
 * for the activation function. If you need an activation function, put it here.
 *
 * @since       1.0.0
 * @return      void
 */
function EDD_RSS_activation() 
{
    /* Activation functions here */
}
register_activation_hook( __FILE__, 'EDD_RSS_activation' );

?>